@@ -24,6 +24,7 @@ my ( $sysconfdir,    # directory for system configuration
 
 my ($cdrom) ;
 
+
 $sysconfdir    = "/etc" ;
 $configname    = "pcd2html.conf" ;
 $pcd_info      = "info.pcd" ;
@@ -132,15 +133,23 @@ my %german = (  "hext",  "_de.html" ,
 	     );
 
 sub GetConvert {
-    # Since ImageMagick 6.0.3 convert uses a new syntax ... that's why
-    # here only the options are provided and convert itself is insertet
-    # in the calling procedure
-    # return "convert -verbose" ;
-    return " -verbose" ;
+    # enable alterative usage of GraphicsMagick
+    return "gm convert $_[0] -verbose" ;
+}
+
+sub GetMontage {
+    # enable alterative usage of GraphicsMagick
+
+    # Du not use the "-debug" option here !!!
+
+    # montage of ImageMagic is broken and the -borderwidth option has to be removed
+    # just live without the border in icons ... especially if
+    # Katrin prefers the icons without the lines ...
+    return "gm montage -label \"\" -bordercolor white -background black -borderwidth 1" ;
 }
 
 sub GetIconConvert {
-    return GetConvert() . " -dither -geometry $IconWidth" . 'x' . "$IconHeight" ;
+    return GetConvert($_[0]) . " -dither -geometry $IconWidth" . 'x' . "$IconHeight" ;
 }
 
 $pcd2html_uti = "pcd2html_uti" ;
@@ -257,7 +266,8 @@ sub pcd_get_keys {
 
     my $i = 0 ;
     foreach ( @pcd_dirs ) {
-	unless ( open(INFO, "$cdrom/$_/$pcd_info" ) ) {
+        my $current_pcd_info = "$cdrom/$_/$pcd_info";
+	unless ( open(INFO, $current_pcd_info ) ) {
 	    warn "Error while opening Kodak Photo CD information at $cdrom/$_/$pcd_info\n" ;
 	    return undef ;
 	}
@@ -271,10 +281,12 @@ sub pcd_get_keys {
 
 	$key = $keys{$info} ;
 	$i  += 1 ;
-	$available_keys{$key} = $_ ;
+	if ( $key ) {
+	    $available_keys{$key} = $_ ;
+	}
 	
 	unless ( $key ) {
-	    print "This Kodak Photo CD was not used before.\n" ;
+	    print "The Kodak Photo CD in $current_pcd_info was not used before.\n" ;
 	    print "Which key should be used in the rules file? " ;
 	    while ( 1 ) {
 		$key = <STDIN> ;
